@@ -34,7 +34,7 @@ class Multiply:
    def setIndexableToChild(self, child, key, index):
       indexable = self.__indexables[key]
       
-      if indexable:
+      if indexable != None:
          child[key] = indexable if "count" not in self.__multiply else indexable[index] if StaticUtils.isIterable(indexable) else "{0}{1}".format(indexable, index + 1 + self.__multiply.get(f"offsetOfIndexIn{key.title()}", Multiply.__DEFAULT_OFFSETS.get(key, 0)))
    
    @property
@@ -117,6 +117,7 @@ class CommonUIComponents:
       from .checkbutton import Checkbutton
       from .entry import Entry
       from .labeledscale import LabeledScale
+      from .spinbox import Spinbox
       
       for tkinterBase in (Button, Canvas, Label, Radiobutton):
          CommonUIComponents.wrapClass(tkinterBase)
@@ -127,7 +128,8 @@ class CommonUIComponents:
          Entry,
          LabeledContainer,
          LabeledRadioButtonGroup,
-         LabeledScale
+         LabeledScale,
+         Spinbox
       ):
          CommonUIComponents.registerClass(smartWidget)
    
